@@ -14,16 +14,15 @@
 ## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with MALDIquantForeign. If not, see <http://www.gnu.org/licenses/>
+## along with MALDIquantForeign. If not, see <https://www.gnu.org/licenses/>
 
-#' @keywords internal
 .importBrukerFlex <- function(file, centroided=FALSE, massRange=c(0, Inf),
                               minIntensity=0, verbose=FALSE, ...) {
 
   s <- readBrukerFlexData::readBrukerFlexFile(fidFile=file, verbose=verbose,
                                               ...)
-  return(list(.createMassObject(data=s$spectrum, metaData=s$metaData,
-                                centroided=centroided, massRange=massRange,
-                                minIntensity=minIntensity, verbose=verbose)))
+  list(.createMassObject(mass=s$spectrum$mass, intensity=s$spectrum$intensity,
+                         metaData=s$metaData, centroided=centroided,
+                         massRange=massRange, minIntensity=minIntensity,
+                         verbose=verbose))
 }
-
